SystemOrganization addCategory: #'ProfStef-Core'!

Object subclass: #AbstractTutorial
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProfStef-Core'!

!AbstractTutorial commentStamp: 'LaurentLaffont 1/21/2010 16:53' prior: 0!
Parent class of all ProfStef tutorials.

To create your own tutorial:
- subclass AbstractTutorial
- implement a few methods which returns a Lesson instance
- implement tutorial which returns a Collection of selectors to the methods you've created.

For example, see MockTutorial (minimalist) and SmalltalkSyntaxTutorial (default ProfStef one).

See ProfStef comment to execute your own tutorial.!

!AbstractTutorial class methodsFor: 'tutorial metainfo' stamp: 'LaurentLaffont 1/27/2010 21:02'!
title	
	"Return the title of the tutorial by parsing the class name 	
	like a Wiki link and interspersing whitespaces between the tokens"	
	| className separators groups |	
			
	className := self name.	
	separators := 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'.	
	groups := className findTokens: separators keep: separators.	
	^' ' join: (groups pairsCollect: [ :sep :rest | sep , rest ]).
! !

!AbstractTutorial class methodsFor: 'tutorial metainfo' stamp: 'LaurentLaffont 11/22/2010 21:36'!
tutorials
	^ (self subclasses 
		sort: [:a :b |
			   a name < b name]) select: [:aTutorial |	
				                                      (aTutorial category = 'ProfStef-Tests') not ].
! !

!AbstractTutorial methodsFor: 'tutorial' stamp: 'DannyChan 2/1/2010 21:21'!
indexOfLesson: aSelector
	^self tutorial indexOf: aSelector.! !

!AbstractTutorial methodsFor: 'tutorial' stamp: 'LaurentLaffont 1/21/2010 13:51'!
lessonAt: anInteger
	| lessonSelector |
	lessonSelector := self tutorial at: anInteger.
	^ self perform: lessonSelector.! !

!AbstractTutorial methodsFor: 'accessing' stamp: 'LaurentLaffont 9/19/2010 16:35'!
lessons
	^ self tutorial collect: [:aSelector| self perform: aSelector]! !

!AbstractTutorial methodsFor: 'printing' stamp: 'LaurentLaffont 2/15/2011 22:47'!
printOn: aStream
	aStream 
		nextPutAll: 'a ProfStef Tutorial (';
		nextPutAll: self class title;
		nextPutAll: ')'.    ! !

!AbstractTutorial methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 13:49'!
size
	^ self tutorial size! !

!AbstractTutorial methodsFor: 'tutorial' stamp: 'LaurentLaffont 1/21/2010 13:44'!
tutorial
	"Should return an Array of selectors which returns Lesson instances.
	See SmalltalkSyntaxTutorial."
	^ self shouldBeImplemented.! !

AbstractTutorial subclass: #HowToMakeYourOwnTutorial
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProfStef-Core'!

!HowToMakeYourOwnTutorial commentStamp: 'LaurentLaffont 2/15/2011 22:20' prior: 0!
I'm a ProfStef tutorial which teach to create a ProfStef tutorial. Open me with

ProfStef goOn: HowToMakeYourOwnTutorial.!

!HowToMakeYourOwnTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 9/21/2010 20:28'!
createLessonFactoryMethods
	^ Lesson 
title: 'Lesson factory methods'
lesson: 
'"Next, create category ''lessons'' and add a method per lesson.

Each method must return a Lesson object.

Your can use Lesson class>>title:lesson: to create Lesson object."

HowToDebug compile:
''useSelfHalt
	^ Lesson
title: ''''self halt''''
lesson: 
''''"Put self halt. in the method you want to debug."

ProfStef next.''''''
classified: ''lessons''.

HowToDebug compile:
''examineStackTrace
	^ Lesson
title: ''''self halt''''
lesson: 
''''"Look at PharoDebug.log."

ProfStef next.''''''
classified: ''lessons''.

HowToDebug compile:
''changeReturnValue
	^ Lesson
title: ''''Change return value''''
lesson: 
''''"Easy in the debugger !!"''''''
classified: ''lessons''.

ProfStef next.'.! !

!HowToMakeYourOwnTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 22:26'!
implementTutorial
	^ Lesson 
title: 'Implement tutorial method'
lesson: 
'"Finally implement the tutorial method to return an Array of your lesson factory methods:"

HowToDebug compile:
''tutorial
	^ #(
#useSelfHalt
#examineStackTrace
#changeReturnValue
)''
classified: ''tutorial''.


ProfStef next.'.! !

!HowToMakeYourOwnTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 22:29'!
runYourTutorial
	^ Lesson 
title: 'Run your tutorial'
lesson: 
'"You can run your fresh new tutorial like this:" 

ProfStef goOn: HowToDebug.'.! !

!HowToMakeYourOwnTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 21:55'!
subclassAbstractTutorial
	^ Lesson 
title: 'AbstractTutorial'
lesson: 
'"Here are the steps to create your own ProfStef tutorial. 

First, create a subclass of AbstractTutorial. For example:"

AbstractTutorial subclass: #HowToDebug
	instanceVariableNames: ''''
	classVariableNames: ''''
	poolDictionaries: ''''
	category: ''ProfStef''.
	
ProfStef next.'! !

!HowToMakeYourOwnTutorial methodsFor: 'tutorial' stamp: 'LaurentLaffont 1/21/2010 21:45'!
tutorial 
	^ #(
subclassAbstractTutorial
createLessonFactoryMethods
implementTutorial
runYourTutorial
)! !

AbstractTutorial subclass: #SmalltalkSyntaxTutorial
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProfStef-Core'!

!SmalltalkSyntaxTutorial commentStamp: 'LaurentLaffont 1/21/2010 16:50' prior: 0!
The default ProfStef tutorial to learn Smalltalk syntax!

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:31'!
basicTypesArray
	^ Lesson
title: 'Basic types: Array' 
lesson: 
'"Literal arrays are created at parse time:"

#(1 2 3).

#( 1 2 3 #(4 5 6)) size.

#(1 2 4) isEmpty.

#(1 2 3) first.

#(''hello'' ''Squeak'') at: 2 put: ''Pharo''; yourself.

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:31'!
basicTypesCharacters
	^ Lesson
title: 'Basic types: Characters' 
lesson: 
'"A Character can be instantiated using $ operator:"

$A.

$A class.

$B charCode.

Character cr.

Character space.

"You can print all 256 characters of the ASCII extended set:"

Character allByteCharacters.

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:31'!
basicTypesDynamicArray
	^ Lesson
title: 'Basic types: Dynamic Array' 
lesson: 
'"Dynamic Arrays are created at execution time:"

{ (2+3) . (6*6) }.

{ (2+3) . (6*6) . ''hello'', '' Stef''} size.


{ ProfStef } first next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 12/13/2010 21:06'!
basicTypesNumbers
	^ Lesson
title: 'Basic types: Numbers' 
lesson: 
'"You now know how to execute Smalltalk code. 

Now let''s talk about basic objects.

1, 2, 100, 2/3 ... are Numbers, and respond to many messages evaluating mathematical expressions.
Evaluate these ones:"

2.

20 factorial.

1000 factorial / 999 factorial.

(1/3).

(1/3) + (4/5).

(1/3) asFloat.

1 class.

1 class maxVal class.

(1 class maxVal + 1) class.

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/27/2010 21:33'!
basicTypesString
	^ Lesson
title: 'Basic types: Strings' 
lesson: 
'"A String is a collection of characters. Use single quotes to create a String object. Print these expressions:"

''ProfStef''.

''ProfStef'' size.

''abc'' asUppercase.

''Hello World'' reverse. 

"You can access each character using at: message"

''ProfStef'' at: 1.

"String concatenation uses the comma operator:"

''ProfStef'', '' is cool''.

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:32'!
basicTypesSymbol
	^ Lesson
title: 'Basic types: Symbols' 
lesson: 
'"A Symbol is a String which is guaranteed to be globally unique. 

There is one and only one Symbol #ProfStef. There may be several ''ProfStef'' String objects.

(Message == returns true if the two objects are the SAME)"

''ProfStef'' asSymbol.

#ProfStef asString.

(2 asString) == (2 asString).

(2 asString) asSymbol == (2 asString) asSymbol.


(Smalltalk at: #ProfStef) next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:33'!
blocks
	^ Lesson
title: 'Blocks' 
lesson: 
'"Cascade is cool !! Let''s talk about blocks.

Blocks are anonymous methods that can be stored into variables and executed on demand.

Blocks are delimited by square brackets: []"

[Browser open].

"does not open a Browser because the block is not executed.

Here is a block that adds 2 to its argument (its argument is named x):"

[:x | x+2].

"We can execute a block by sending it value messages."

[:x | x+2] value: 5.

[Browser open] value.

[:x | x+2] value: 10.

[:x :y| x + y] value:3 value:5.

[ProfStef next] value.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:33'!
blocksAssignation
	^ Lesson
title: 'Block assignation' 
lesson: 
'"Blocks can be assigned to a variable then executed later.

Note that |b| is the declaration of a variable named ''b'' and that '':='' assigns a value to a variable.

Select the three lines then Print It:"

|b|
b := [:x | x+2].
b value: 12.


ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:33'!
conditionals
	^ Lesson
title: 'Conditionals' 
lesson: 
'"Conditionals are just messages sent to Boolean objects"

1 < 2
  ifTrue: [100]
  ifFalse: [42].

"Here the message is ifTrue:ifFalse

Try this:"

Transcript open.

3 > 10 
	ifTrue: [Transcript show: ''maybe there''''s a bug ....'']
	ifFalse: [Transcript show: ''No : 3 is less than 10''].

3 = 3 ifTrue: [ProfStef next].'.! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 12/12/2010 18:30'!
debugger
	^ Lesson
title: 'Debugger' 
lesson: '"The Debugger may be the most famous tool of Smalltalk environments. It will open as soon as an unmanaged Exception occurs. 

The following code will open the debugger on the message stack, select SmalltalkSyntaxTutorial>>divideTwoByZero".

SmalltalkSyntaxTutorial new divideTwoByZero. '! !

!SmalltalkSyntaxTutorial methodsFor: 'interactive' stamp: 'AlainPlantec 8/27/2011 01:07'!
divideTwoByZero
	2/0.
	
	"Oups!! 2/0 raises a ZeroDivide exception.  So the debugger opens to let you fix the code.
	
	- Remove the line of code above.
	- Right-click and select 'Accept' to compile the new version of the method
	- click the button 'Proceed' to continue execution.
	".
	ProfStef next. ! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 16:42'!
doingVSPrinting 
	^ Lesson
title: 'Doing VS Printing: Doing' 
lesson: 
'"Cool !! (I like to say Cooool :) ). You''ve just executed a Smalltalk expression. More precisely, you sent the message ''next'' to ProfStef class (it''s me !!).

Note you can run this tutorial again by evaluating: ''ProfStef go''. 
''ProfStef previous'' returns to the previous lesson.

You can also Do It using the keyboard shortcut ''ALT d''
(this varies according to your operating system/computer: it can be ''CMD d'' or ''CTRL d''). 

Try to evaluate these expressions:"

Browser open.

SmalltalkImage current aboutThisSystem.

"Then go to the next lesson:"

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'initialize-release' stamp: 'LaurentLaffont 12/12/2010 17:18'!
initialize
	super initialize.
	self prepareDebuggerExample.! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 2/15/2011 22:22'!
instanciation
	^ Lesson
title: 'Instanciation' 
lesson: 
'"Objects are instances of their class. Usually, we send the message #new to a class for creating an instance of this class.

The message #allInstances sent to a class answers an Array with all instances of this class.

For example, let''s look at how many instances of SimpleButtonMorph exist:"

SimpleButtonMorph allInstances size.

"Now create a new instance of it:"

SimpleButtonMorph new
	label: ''A nice button'';
	openCenteredInWorld.

"See the button centered on the world ? The list of all instances should contains one more instance:"

SimpleButtonMorph allInstances size.

"Let''s play with it:"

SimpleButtonMorph allInstances last 
	label: ''ProfStef is cooooool !!'';
	color: Color cyan.
	
"Let''s delete it and ask the system to clean the memory:"

SimpleButtonMorph allInstances last delete.
Smalltalk garbageCollect.
SimpleButtonMorph allInstances size.

"Click on the button to go to next lesson:"

SimpleButtonMorph new
	label: ''Go to next lesson'';
	target: [ProfStef next. 
			SimpleButtonMorph allInstances last delete];
	actionSelector: #value;
	openCenteredInWorld.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:34'!
iterators
	^ Lesson
title: 'Iterators' 
lesson: 
'"The message do: is sent to a collection of objects (Array, Set, OrderedCollection), evaluating the block for each element.

Here we want to print all the numbers on the Transcript (a console)"

#(11 38 3 -2 10) do: [:each |
     Transcript show: each printString; cr].

"Some other really nice iterators"

#(11 38 3 -2 10) collect: [:each | each abs].

#(11 38 3 -2 10) collect: [:each | each odd].

#(11 38 3 -2 10) select: [:each | each odd].

#(11 38 3 -2 10) select: [:each | each > 10].

#(11 38 3 -2 10) reject: [:each | each > 10].

#(11 38 3 -2 10) 
     do: [:each | Transcript show: each printString]
     separatedBy: [Transcript show: ''.''].


ProfStef allInstances do: [:aProfStef | aProfStef next].'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:34'!
loops
	^ Lesson
title: 'Loops' 
lesson: 
'"Loops are high-level collection iterators, implemented as regular methods."

"Basic loops:
  to:do:
  to:by:do"

1 to: 100 do:
  [:i | Transcript show: i asString; cr ].

1 to: 100 by: 3 do: [:i | Transcript show: i asString; cr].

100 to: 0 by: -2 do: 
    [:i | Transcript show: i asString; cr].

1 to: 1 do: [:i | ProfStef next].'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:34'!
mathematicalPrecedence
	^ Lesson
title: 'Mathematical precedence'
lesson: 
'"Traditional precedence rules from mathematics do not follow in Smalltalk."

2 * 10 + 2.

"Here the message * is sent to 2, which answers 20, then 20 receive the message +

Remember that all messages always follow a simple left-to-right precedence rule, * without exceptions *."

2 + 2 * 10.

2 + (2 * 10).

8 - 5 / 2.

(8 - 5) / 2.

8 - (5 / 2).

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/27/2010 21:27'!
messageSyntaxBinary
	^ Lesson
title: 'Message syntax: Binary messages' 
lesson: 
'"Binary messages have the following form:
    anObject + anotherObject"

3 * 2.

Date today + 3 weeks.

false | false.

true & true.

true & false.

10 @ 100.

10 <= 12.

''ab'', ''cd''.

Date today < Date yesterday.

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:35'!
messageSyntaxCascade
	^ Lesson
title: 'Message syntax: Cascade' 
lesson: 
'"; is the cascade operator. It''s useful to send message to the SAME receiver
Open a Transcript (console):"

Transcript open.

"Then:"

Transcript show: ''hello''.
Transcript show: ''Smalltalk''.
Transcript cr.

"is equivalent to:"

Transcript 
	   show: ''hello'';
	   show: ''Smalltalk'' ;
	   cr.

"Try to go to the next lesson with a cascade of two ''next'' messages:"

ProfStef'.! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:35'!
messageSyntaxCascadeShouldNotBeHere
	^ Lesson
title: 'Lost ?' 
lesson: 
'"Hey, you should not be here !!!! 

Go back and use a cascade !!"

ProfStef previous.'.! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 12/13/2010 21:09'!
messageSyntaxExecutionOrder
	^ Lesson
title: 'Message syntax: Execution order' 
lesson: 
'"Unary messages are executed first, then binary messages and finally keyword messages:
    Unary > Binary > Keywords"

2 + 3 squared.

2 raisedTo: 3 + 2.
  
(0@0) class.

0@0 corner: 100@200.

(0@0 corner: 100@200) class.

"Between messages of similar precedence, expressions are executed from left to right"

-3 abs negated reciprocal.

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:35'!
messageSyntaxExecutionOrderParentheses
	^ Lesson
title: 'Message syntax: Parentheses'
lesson: 
'"Use parentheses to change order of evaluation"

(2 + 3) squared.

(2 raisedTo: 3) + 2.

(0@0 extent: 100@200) bottomRight.

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:35'!
messageSyntaxKeyword
	^ Lesson
title: 'Message syntax: Keyword messages' 
lesson: 
'"Keyword Messages are messages with arguments. They have the following form:
    anObject akey: anotherObject akey2: anotherObject2"

4 between: 0 and: 10.

"The message is between:and: sent to the Number 4"

1 max: 3.

Color r:1 g:0 b:0.

"The message is r:g:b: implemented on class Color. Note you can also write"

Color
	r:1
	g:1
	b:0.
	
ProfStef perform: #next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/27/2010 21:40'!
messageSyntaxUnary
	^ Lesson
title: 'Message syntax: Unary messages' 
lesson: 
'"Messages are sent to objects. There are three types of message: Unary, Binary and Keyword.

Unary messages have the following form:
    anObject aMessage 

You''ve already sent unary messages. For example:"

1 class.

false not.

Time now.

Date today.

Float pi.

"And of course: "

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/27/2010 21:41'!
pharoEnvironment
	^ Lesson
title: 'Pharo environment' 
lesson: 
'"Every Smalltalk system is full of objects. There are windows, text, numbers, dates, colors, points and much more. You can interact with objects in a much more direct way than is possible with other programming languages.

Every object understands the message ''explore''. As a result, you get an Explorer window that shows details about the object."

Date today explore.

"This shows that the date object consists of a point in time (start) and a duration (one day long)."

ProfStef explore.

"You see, ProfStef class has a lot of objects. Let''s take a look at my code:"

ProfStef browse.

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'interactive' stamp: 'LaurentLaffont 12/12/2010 17:16'!
prepareDebuggerExample

	self class compile: 'divideTwoByZero
	2/0.
	
	"Oups!! 2/0 raises a ZeroDivide exception.  So the debugger opens to let you fix the code.
	
	- Remove the line of code above.
	- Right-click and select ''Accept'' to compile the new version of the method
	- click the button ''Proceed'' to continue execution.
	".
	ProfStef next. '
	
	classified: 'interactive'.! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:36'!
printing 
	^ Lesson
title: 'Doing VS Printing: Printing' 
lesson: 
'"Now you''re a Do It master !! Let''s talk about printing. It''s a Do It which prints the result next to the expression you''ve selected.
For example, select the text below, open the menu and click on ''print it (p)'':"

1 + 2.

"You''ve seen the letter ''p'' between parentheses next to ''print it'' ? It indicates the ALT- shortcut to execute this command.

Try ALT-p on the following expressions:"

Date today.

Time now.

"The result is selected, so you can erase it using the backspace key. Try it !!"

SmalltalkImage  current datedVersion.

ProfStef next.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 12/13/2010 21:57'!
reflection
	^ Lesson
title: 'Reflection' 
lesson: 
'"You can inspect and change the system at runtime.

Take a look at method #ifFalse:ifTrue: source code of class True:"

(True>>#ifFalse:ifTrue:) definition.

"Or just its comment:"

(True>>#ifFalse:ifTrue:) comment.

"Here''s all the methods I implement:"

ProfStef selectors.


"Let''s create a new method to go to the next lesson:"

ProfStef class compile:''goToNextLesson
  self next''.

"Wow !! I can''t wait to use my new method !! "

ProfStef goToNextLesson.'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 12/13/2010 22:06'!
reflectionContinued
	^ Lesson
title: 'Reflection continued' 
lesson: 
'"So cool, isn''t it ?  Before going further, let''s remove this method:"

ProfStef respondsTo: #goToNextLesson.

ProfStef class removeSelector: #goToNextLesson.

ProfStef respondsTo: #goToNextLesson.


"Then move forward:"

ProfStef default executeMethod: (ProfStef lookupSelector:#next).'! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/27/2010 21:09'!
theEnd
	^ Lesson
title: 'Tutorial done !!' 
lesson: 
'"This tutorial is done. Enjoy programming Smalltalk with Pharo. 

Don''t forget to read ''Pharo By Example'' found here: http://pharo-project.org/PharoByExample.

You can run this tutorial again by evaluating: ProfStef go.

Do you want to create your own interactive tutorial with ProfStef ? That''s very easy!!!!  How ? There''s a ProfStef interactive tutorial for that :D
Just evaluate the following code:

ProfStef goOn: HowToMakeYourOwnTutorial

See you soon !!"
'! !

!SmalltalkSyntaxTutorial methodsFor: 'tutorial' stamp: 'LaurentLaffont 2/6/2011 19:05'!
tutorial
^ #(
welcome
doingVSPrinting
printing

basicTypesNumbers
basicTypesCharacters
basicTypesString
basicTypesSymbol
basicTypesArray
basicTypesDynamicArray

messageSyntaxUnary
messageSyntaxBinary
messageSyntaxKeyword
messageSyntaxExecutionOrder
messageSyntaxExecutionOrderParentheses
mathematicalPrecedence
messageSyntaxCascade
messageSyntaxCascadeShouldNotBeHere

blocks
blocksAssignation
conditionals
loops
iterators

instanciation

reflection
reflectionContinued

pharoEnvironment
debugger

theEnd
)! !

!SmalltalkSyntaxTutorial methodsFor: 'lessons' stamp: 'LaurentLaffont 1/21/2010 13:36'!
welcome
	^ Lesson
title: 'Welcome' 
lesson: 
'"Hello!! I''m Professor Stef.

You must want me to help you learn Smalltalk.

So let''s go to the first lesson.  Select the text below, right-click and choose ''do it (d)''"

ProfStef next.'! !

Object subclass: #Lesson
	instanceVariableNames: 'title lesson'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProfStef-Core'!

!Lesson commentStamp: 'LaurentLaffont 1/15/2010 10:25' prior: 0!
See class side messages #welcome, #doingVSPrinting....
!

!Lesson class methodsFor: 'instance creation' stamp: 'LaurentLaffont 1/15/2010 09:27'!
title: aStringForTitle lesson: aStringForLesson
	^ self new title: aStringForTitle; lesson: aStringForLesson; yourself.! !

!Lesson methodsFor: 'accessing' stamp: 'LaurentLaffont 1/15/2010 09:25'!
lesson
	^ lesson ifNil: [lesson := '']! !

!Lesson methodsFor: 'accessing' stamp: 'LaurentLaffont 1/15/2010 09:25'!
lesson: aString
	lesson := aString! !

!Lesson methodsFor: 'printing' stamp: 'LaurentLaffont 2/15/2011 22:46'!
printOn: aStream
	super printOn: aStream.  
	aStream 
		nextPutAll: '(';
		nextPutAll: self title;
		nextPutAll: ')'.    ! !

!Lesson methodsFor: 'accessing' stamp: 'LaurentLaffont 1/15/2010 09:25'!
title
	^ title ifNil: [title := '']! !

!Lesson methodsFor: 'accessing' stamp: 'LaurentLaffont 1/15/2010 09:25'!
title: aString
	title := aString! !

Object subclass: #LessonView
	instanceVariableNames: 'shoutMorph window'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProfStef-Core'!

!LessonView commentStamp: 'LaurentLaffont 1/15/2010 10:24' prior: 0!
A LessonView displays a Lesson instance!

!LessonView methodsFor: 'gui' stamp: 'LaurentLaffont 1/21/2010 21:01'!
close
	self window delete.! !

!LessonView methodsFor: 'gui' stamp: 'LaurentLaffont 1/27/2010 21:21'!
menu
	^ MenuMorph fromArray: {
			{'do it (d)' translated. #doIt}.
			{'print it (p)' translated. #printIt}}.! !

!LessonView methodsFor: 'gui' stamp: 'AlainPlantec 8/26/2011 22:18'!
open	
	shoutMorph  := PluggableTextMorph 
		on: self 
		text: nil
		accept: nil
		readSelection: nil 
		menu: #shoutMorphFillMenu:.
	shoutMorph
		styled: false;
		setText: ''.
	window  := SystemWindow labelled: 'PrStef lesson'.
	window addMorph: shoutMorph  frame: (0@0 corner: 1@1).
	window openInWorld.! !

!LessonView methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 20:58'!
shoutMorph
	^ shoutMorph ifNil: [self open. shoutMorph]! !

!LessonView methodsFor: 'gui' stamp: 'LaurentLaffont 1/21/2010 21:00'!
shoutMorphFillMenu: aMenu
	^ aMenu addAllFrom: self menu! !

!LessonView methodsFor: 'gui' stamp: 'LaurentLaffont 1/21/2010 21:01'!
showLesson: aLesson withTitle: aString
	self window setLabel: aString.
	self shoutMorph 
		setText: aLesson lesson; 
		selectFrom:0 to:0.
	! !

!LessonView methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 21:06'!
text
	^ self shoutMorph text asString! !

!LessonView methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 21:02'!
window 
	^ window ifNil: [self open. window]! !

Object subclass: #ProfStef
	instanceVariableNames: 'lessonView player'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProfStef-Core'!

ProfStef class
	instanceVariableNames: 'instance'!

!ProfStef commentStamp: '<historical>' prior: 0!
A ProfStef is the Smalltalk teacher. To start the tutorial, evaluate:
ProfStef go.

To go to the next lesson evaluate:
ProfStef next.

To execute your own tutorial:
ProfStef goOn: MyOwnTutorial

To see a table of contents with all defined tutorials:
ProfStef contents!

ProfStef class
	instanceVariableNames: 'instance'!

!ProfStef class methodsFor: 'class initialization' stamp: 'LaurentLaffont 1/21/2010 17:15'!
default 
	^ instance ifNil: [instance := self new]! !

!ProfStef class methodsFor: 'navigating' stamp: 'DannyChan 2/9/2010 19:30'!
first
	^ self default first.! !

!ProfStef class methodsFor: 'navigating' stamp: 'tg 2/1/2010 16:01'!
go
	instance := nil.
	^ self default go.! !

!ProfStef class methodsFor: 'navigating' stamp: 'tg 2/1/2010 16:01'!
goOn: aTutorialClass
	instance := nil.
	^ self default goOn: aTutorialClass.! !

!ProfStef class methodsFor: 'navigating' stamp: 'DannyChan 2/9/2010 19:30'!
last
	^ self default last.! !

!ProfStef class methodsFor: 'navigating' stamp: 'tg 2/1/2010 16:01'!
next
	^ self default next.! !

!ProfStef class methodsFor: 'navigating' stamp: 'tg 2/1/2010 16:01'!
previous
	^ self default previous.! !

!ProfStef class methodsFor: 'starting' stamp: 'DannyChan 2/1/2010 19:23'!
tutorial: aTutorialClass lesson: aSelector
	self default tutorial: aTutorialClass lesson: aSelector.! !

!ProfStef class methodsFor: 'starting' stamp: 'DannyChan 2/1/2010 19:23'!
tutorial: aTutorialClass lessonAt: lessonIndex
	self default tutorial: aTutorialClass lessonAt: lessonIndex.! !

!ProfStef methodsFor: 'gui' stamp: 'LaurentLaffont 1/21/2010 21:05'!
close
	self lessonView close! !

!ProfStef methodsFor: 'navigating' stamp: 'DannyChan 2/9/2010 19:28'!
first
	self player first.
	^ self showCurrentLesson.! !

!ProfStef methodsFor: 'starting' stamp: 'tg 2/1/2010 16:02'!
go
	^ self goOn: SmalltalkSyntaxTutorial.! !

!ProfStef methodsFor: 'starting' stamp: 'tg 2/1/2010 16:02'!
goOn: aTutorialClass
	self player tutorial: aTutorialClass new.
	^ self open.! !

!ProfStef methodsFor: 'navigating' stamp: 'DannyChan 2/9/2010 19:28'!
last
	self player last.
	^ self showCurrentLesson.! !

!ProfStef methodsFor: 'accessing' stamp: 'DannyChan 2/2/2010 19:39'!
lessonView
	^ lessonView ifNil: [lessonView := LessonView new]! !

!ProfStef methodsFor: 'accessing' stamp: 'DannyChan 2/2/2010 19:16'!
lessonView: aLessonView
	lessonView := aLessonView.! !

!ProfStef methodsFor: 'navigating' stamp: 'tg 2/1/2010 16:02'!
next
	self player next.
	^ self showCurrentLesson.! !

!ProfStef methodsFor: 'gui' stamp: 'tg 2/1/2010 16:02'!
open
	self player first.
	^ self showCurrentLesson.! !

!ProfStef methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 20:38'!
player 
	^ player ifNil: [player := TutorialPlayer new]! !

!ProfStef methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 20:39'!
player: aTutorialPlayer
	player := aTutorialPlayer.! !

!ProfStef methodsFor: 'navigating' stamp: 'tg 2/1/2010 16:02'!
previous
	self player previous.
	^ self showCurrentLesson.! !

!ProfStef methodsFor: 'gui' stamp: 'LaurentLaffont 2/15/2011 22:14'!
showCurrentLesson
	| progressInfo lesson position size |
	lesson := self player currentLesson.
	progressInfo := '(', self tutorialPositionString, '/', self tutorialSizeString, ')'. 
	^ self lessonView   showLesson: lesson withTitle: lesson title, ' ', progressInfo.
	
! !

!ProfStef methodsFor: 'navigating' stamp: 'DannyChan 2/1/2010 21:23'!
tutorial: aTutorialClass lesson: aSelector
	| tutorial |
	tutorial := aTutorialClass new.
	self player tutorial: tutorial.
	self tutorial: aTutorialClass lessonAt: (tutorial indexOfLesson: aSelector).! !

!ProfStef methodsFor: 'navigating' stamp: 'DannyChan 2/1/2010 19:23'!
tutorial: aTutorialClass lessonAt: lessonIndex
	self player tutorial: aTutorialClass new.
	self player tutorialPosition: lessonIndex.
	self showCurrentLesson.! !

!ProfStef methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 20:37'!
tutorialPositionString
	^ player tutorialPosition asString.! !

!ProfStef methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 20:38'!
tutorialSizeString
	^ self player size asString! !

Object subclass: #TutorialPlayer
	instanceVariableNames: 'tutorialPosition tutorial'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ProfStef-Core'!

!TutorialPlayer commentStamp: 'LaurentLaffont 1/21/2010 20:34' prior: 0!
I can navigate through an AbstractTutorial subclass. With #next and #previous you can go forward and backward through the tutorial. !

!TutorialPlayer methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 15:37'!
currentLesson
	^ self tutorial lessonAt: self tutorialPosition.! !

!TutorialPlayer methodsFor: 'navigating' stamp: 'LaurentLaffont 1/21/2010 20:43'!
first
	self rewind.
	^ self currentLesson! !

!TutorialPlayer methodsFor: 'navigating' stamp: 'DannyChan 2/9/2010 19:29'!
last
	tutorialPosition := self size.
	^ self currentLesson! !

!TutorialPlayer methodsFor: 'navigating' stamp: 'LaurentLaffont 1/21/2010 15:40'!
next
	self tutorialPosition < self size
		ifTrue: [tutorialPosition := tutorialPosition + 1].
	^ self currentLesson! !

!TutorialPlayer methodsFor: 'navigating' stamp: 'LaurentLaffont 1/18/2010 12:53'!
previous
	tutorialPosition >  1 ifTrue: [tutorialPosition := tutorialPosition  - 1].
	^ self currentLesson! !

!TutorialPlayer methodsFor: 'navigating' stamp: 'LaurentLaffont 1/21/2010 20:43'!
rewind
	tutorialPosition := 1.! !

!TutorialPlayer methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 13:40'!
size
	^ self tutorial size! !

!TutorialPlayer methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 15:19'!
tutorial
	^ tutorial  ifNil: [tutorial := SmalltalkSyntaxTutorial new]! !

!TutorialPlayer methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 15:22'!
tutorial: aTutorial
	tutorial := aTutorial! !

!TutorialPlayer methodsFor: 'accessing' stamp: 'LaurentLaffont 1/21/2010 20:43'!
tutorialPosition 
	^ tutorialPosition  ifNil: [
		self rewind.
		tutorialPosition.
	].
	! !

!TutorialPlayer methodsFor: 'accessing' stamp: 'DannyChan 2/1/2010 19:25'!
tutorialPosition: aTutorialPosition 
	tutorialPosition := aTutorialPosition 
	! !
